@@ -6,3 +6,8 @@ from . import binaryio
 from . import query
 from . import queryparser
 from .oktavia import *
+
+try:
+    from . import _bitvector as native_bitvector
+except ImportError:
+    pass
